;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "calle24" "20251111.1755"
  "Emacs Toolbar Support for SF Symbols."
  '((emacs "29.1"))
  :url "https://github.com/kickingvegas/calle24"
  :commit "a0b3ff3333fcc44f332ea0e3e04d0392bec2991e"
  :revdesc "a0b3ff3333fc"
  :keywords '("tools")
  :authors '(("Charles Choi" . "kickingvegas@gmail.com"))
  :maintainers '(("Charles Choi" . "kickingvegas@gmail.com")))
